==> components-2.0.10.tgz: package/esm/Atoms/Links/Link.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from 'react';
import styled from 'styled-components';
import PropTypes from 'prop-types';
var Wrapper =
/*#__PURE__*/
styled.a.withConfig({
  componentId: "sc-1r996ns-0"
})(["font-family:", ";font-weight:", ";font-size:", ";text-transform:", ";font-style:", ";color:", ";opacity:", ";cursor:pointer;text-decoration:none;&:hover{color:", ";text-decoration:none;}"], function (props) {
  return props.theme['fontPrimary'];
}, function (props) {
  return props.weight;
}, function (props) {
  return props.size;
}, function (props) {
  return props.uppercase ? 'uppercase' : props.capitalize ? 'capitalize' : 'none';
}, function (props) {
  return props.italic ? 'italic' : 'normal';
}, function (props) {
  return props.theme['linkColor'];
}, function (props) {
  return props.opacity;
}, function (props) {
  return props.theme['linkHoverColor'];
});

var Link = function Link(_ref) {
  var children = _ref.children,
      rest = _objectWithoutProperties(_ref, ["children"]);

  return React.createElement(Wrapper, rest, children);
};

Link.propTypes = process.env.NODE_ENV !== "production" ? {
  capitalize: PropTypes.bool,
  children: PropTypes.node,
  italic: PropTypes.bool,
  opacity: PropTypes.number,
  size: PropTypes.string,
  uppercase: PropTypes.bool,
  weight: PropTypes.oneOf([100, 200, 300, 400, 500, 600, 700])
} : {};
Link.defaultProps = {
  capitalize: false,
  italic: false,
  opacity: 1,
  size: '1rem',
  uppercase: false,
  weight: 400
};
export default Link;

==> components-2.0.12.tgz: package/esm/Atoms/Links/Link.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from 'react';
import styled from 'styled-components';
import PropTypes from 'prop-types';
var Wrapper =
/*#__PURE__*/
styled.a.withConfig({
  componentId: "sc-1r996ns-0"
})(["\n  font-family: ", ";\n  font-weight: ", ";\n  font-size: ", ";\n  text-transform: ", ";\n  font-style: ", ";\n  color: ", ";\n  opacity: ", ";\n  cursor: pointer;\n  text-decoration: none;\n\n  &:hover {\n    color: ", ";\n    text-decoration: none;\n  }\n"], function (props) {
  return props.theme['fontPrimary'];
}, function (props) {
  return props.weight;
}, function (props) {
  return props.size;
}, function (props) {
  return props.uppercase ? 'uppercase' : props.capitalize ? 'capitalize' : 'none';
}, function (props) {
  return props.italic ? 'italic' : 'normal';
}, function (props) {
  return props.theme['linkColor'];
}, function (props) {
  return props.opacity;
}, function (props) {
  return props.theme['linkHoverColor'];
});

var Link = function Link(_ref) {
  var children = _ref.children,
      rest = _objectWithoutProperties(_ref, ["children"]);

  return React.createElement(Wrapper, rest, children);
};

Link.propTypes = process.env.NODE_ENV !== "production" ? {
  capitalize: PropTypes.bool,
  children: PropTypes.node,
  italic: PropTypes.bool,
  opacity: PropTypes.number,
  size: PropTypes.string,
  uppercase: PropTypes.bool,
  weight: PropTypes.oneOf([100, 200, 300, 400, 500, 600, 700])
} : {};
Link.defaultProps = {
  capitalize: false,
  italic: false,
  opacity: 1,
  size: '1rem',
  uppercase: false,
  weight: 400
};
export default Link;
